/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: RCSL 1.0/RPSL 1.0 
 *  
 * Portions Copyright (c) 1995-2002 RealNetworks, Inc. All Rights Reserved. 
 *      
 * The contents of this file, and the files included with this file, are 
 * subject to the current version of the RealNetworks Public Source License 
 * Version 1.0 (the "RPSL") available at 
 * http://www.helixcommunity.org/content/rpsl unless you have licensed 
 * the file under the RealNetworks Community Source License Version 1.0 
 * (the "RCSL") available at http://www.helixcommunity.org/content/rcsl, 
 * in which case the RCSL will apply. You may also obtain the license terms 
 * directly from RealNetworks.  You may not use this file except in 
 * compliance with the RPSL or, if you have a valid RCSL with RealNetworks 
 * applicable to this file, the RCSL.  Please see the applicable RPSL or 
 * RCSL for the rights, obligations and limitations governing use of the 
 * contents of the file.  
 *  
 * This file is part of the Helix DNA Technology. RealNetworks is the 
 * developer of the Original Code and owns the copyrights in the portions 
 * it created. 
 *  
 * This file, and the files included with this file, is distributed and made 
 * available on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESS OR IMPLIED, AND REALNETWORKS HEREBY DISCLAIMS ALL SUCH WARRANTIES, 
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS 
 * FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT. 
 * 
 * Technology Compatibility Kit Test Suite(s) Location: 
 *    http://www.helixcommunity.org/content/tck 
 * 
 * Contributor(s): 
 *  
 * ***** END LICENSE BLOCK ***** */ 

#ifndef _NPTIME_H_
#define _NPTIME_H_

class NPTime
{
public:

    // constructors
    NPTime();
    NPTime(INT32 sec, INT32 uSec);
    NPTime(INT32 mSec);
    NPTime(const char* pTimeString /* format [dd:[hh:[mm:]]]ssss[.uuuuu] */);
    NPTime(const char* pTimeString,
		/* If TRUE, allows format [xyz]['h'|'min'|'s'|'ms'] as in
		   "23min":    */
		BOOL bAllow_h_min_s_ms_units, BOOL& bSucceeded);
    NPTime(const NPTime& lhs);

    // assignment
    NPTime& operator=(const NPTime& lhs);

    // conversion
    operator const char*();
    operator UINT32();

    // arithmetic
    NPTime operator+(const NPTime& lhs);
    NPTime operator-(const NPTime& lhs);
    NPTime& operator+=(const NPTime& lhs);
    NPTime& operator-=(const NPTime& lhs);

    // comparison
    INT32 compare(const NPTime& lhs) const;

    INT32 m_lSecond;
    INT32 m_lMicroSecond;

private:
    void normalize();
    const char* toString();
    void fromString(const char* pNPTimeString);
    void fromMSec(INT32 mSec);
    INT32 toMSec();
    CHXString m_asString;
};

inline BOOL operator==(const NPTime& t1, const NPTime& t2)
{
    return t1.compare(t2) == 0;
}

inline BOOL operator!=(const NPTime& t1, const NPTime& t2)
{
    return t1.compare(t2) != 0;
}

inline BOOL operator<(const NPTime& t1, const NPTime& t2)
{
    return t1.compare(t2) < 0;
}

inline BOOL operator>(const NPTime& t1, const NPTime& t2)
{
    return t1.compare(t2) > 0;
}

inline BOOL operator<=(const NPTime& t1, const NPTime& t2)
{
    return t1.compare(t2) <= 0;
}

inline BOOL operator>=(const NPTime& t1, const NPTime& t2)
{
    return t1.compare(t2) >= 0;
}

#endif /* _NPTIME_H_ */
